==> kubernetes-model-discovery-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/ForZoneBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ForZoneBuilder extends ForZoneFluentImpl<ForZoneBuilder> implements VisitableBuilder<ForZone,ForZoneBuilder>{
  public ForZoneBuilder() {
    this(false);
  }
  public ForZoneBuilder(Boolean validationEnabled) {
    this(new ForZone(), validationEnabled);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent) {
    this(fluent, false);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ForZone(), validationEnabled);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,ForZone instance) {
    this(fluent, instance, false);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,ForZone instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ForZoneBuilder(ForZone instance) {
    this(instance,false);
  }
  public ForZoneBuilder(ForZone instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ForZoneFluent<?> fluent;
  Boolean validationEnabled;
  public ForZone build() {
    ForZone buildable = new ForZone(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-discovery-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/ForZoneBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ForZoneBuilder extends ForZoneFluent<ForZoneBuilder> implements VisitableBuilder<ForZone,ForZoneBuilder>{
  public ForZoneBuilder() {
    this(false);
  }
  public ForZoneBuilder(Boolean validationEnabled) {
    this(new ForZone(), validationEnabled);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent) {
    this(fluent, false);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ForZone(), validationEnabled);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,ForZone instance) {
    this(fluent, instance, false);
  }
  public ForZoneBuilder(ForZoneFluent<?> fluent,ForZone instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ForZone());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ForZoneBuilder(ForZone instance) {
    this(instance,false);
  }
  public ForZoneBuilder(ForZone instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ForZone());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ForZoneFluent<?> fluent;
  Boolean validationEnabled;
  public ForZone build() {
    ForZone buildable = new ForZone(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
